pub enum Error {
Show 15 variants
Network(String),
Parsing(String),
Crypto(String),
Html(String),
Credentials(String),
UntisAPI(String),
DateTime(String),
Threading(String),
SchoolNotFound(String),
KeyPair,
LoginTimeout(u32),
LessonUploadError(LessonUploadError),
ServerSide(String),
FileSystem(String),
InvalidInput(String),
}Variants
Network(String)
Parsing(String)
Happens if anything goes wrong with parsing
Crypto(String)
Html(String)
Credentials(String)
Happens if something goes wrong when logging into Untis
UntisAPI(String)
Happens if anything goes wrong while accessing the Untis API
DateTime(String)
Happens if anything goes wrong when processing Dates and/or Times
Threading(String)
Happens if something goes wrong with Threads (like tokio::task::spawn_blocking
SchoolNotFound(String)
Happens if no school with the provided id is found
KeyPair
Happens if key_pair generation fails
LoginTimeout(u32)
Happens if the user tried to log in to often with the same password. The u32 contains the timeout in seconds
LessonUploadError(LessonUploadError)
Happens if anything goes wrong with uploading a file in Lessons
ServerSide(String)
Some other Error that may be an issue with the provided values or with the lanis backend
FileSystem(String)
Happens if anything goes wrong when interacting with the file system
InvalidInput(String)
Happens if any input is invalid