pub struct Lesson {
pub id: i32,
pub url: String,
pub name: String,
pub teacher: String,
pub teacher_short: Option<String>,
pub attendances: BTreeMap<String, String>,
pub entry_latest: Option<LessonEntry>,
pub entries: Option<Vec<LessonEntry>>,
pub marks: Option<Vec<LessonMark>>,
pub exams: Option<Vec<LessonExam>>,
}Fields
id: i32url: Stringname: Stringteacher: Stringteacher_short: Option<String>Should always be Some if nothing went wrong
attendances: BTreeMap<String, String>entry_latest: Option<LessonEntry>If this is None there is no latest entry
entries: Option<Vec<LessonEntry>>Will be empty if no entries are found and None if this value wasn’t initialized
marks: Option<Vec<LessonMark>>Will be empty if no marks are found and None if this value wasn’t initialized
exams: Option<Vec<LessonExam>>Will be empty if no exams are found and None if this value wasn’t initialized
Implementations