pub struct ConversationOverview {
pub id: i32,
pub uid: String,
pub sender: Participant,
pub receiver: Vec<Participant>,
pub subject: String,
pub date_time: DateTime<Utc>,
pub read: bool,
pub visible: bool,
}Fields
id: i32uid: Stringsender: Participantreceiver: Vec<Participant>subject: Stringdate_time: DateTime<Utc>read: boolvisible: boolImplementations
Sourceimpl ConversationOverview
impl ConversationOverview
Sourcepub async fn get_root(
client: &Client,
keys: &LanisKeyPair,
) -> Result<Vec<ConversationOverview>, Error>
pub async fn get_root( client: &Client, keys: &LanisKeyPair, ) -> Result<Vec<ConversationOverview>, Error>
Get all ConversationOverview’s (hidden and visible)
Sourcepub async fn hide(&mut self, client: &Client) -> Result<bool, Error>
pub async fn hide(&mut self, client: &Client) -> Result<bool, Error>
Hides a visible conversation and returns the result if the hiding succeeded
Sourcepub async fn show(&mut self, client: &Client) -> Result<bool, Error>
pub async fn show(&mut self, client: &Client) -> Result<bool, Error>
Shows a hidden conversation and returns the result if the hiding succeeded
Sourcepub async fn get(
&self,
client: &Client,
keys: &LanisKeyPair,
) -> Result<Conversation, Error>
pub async fn get( &self, client: &Client, keys: &LanisKeyPair, ) -> Result<Conversation, Error>
Get the full Conversation